@@ -37,25 +37,29 @@ class CloudStorageGenerator(GCPGenerator):
         )
     }
 
-    LABELS = (("[{'key': 'test_storage_key', 'value': 'test_storage_label'}]"), ("[]"))
+    LABELS = (([{"key": "test_storage_key", "value": "test_storage_label"}]), ([]))
 
     SYSTEM_LABELS = (("[]"),)
 
     def __init__(self, start_date, end_date, project, attributes=None):
         """Initialize the cloud storage generator."""
         super().__init__(start_date, end_date, project, attributes)
+        self.credit_total = 0
         if self.attributes:
-            if self.attributes.get("tags"):
-                self._tags = self.attributes.get("tags")
+            if self.attributes.get("labels"):
+                self._labels = self.attributes.get("labels")
             if self.attributes.get("usage.amount"):
                 self._usage_amount = self.attributes.get("usage.amount")
             if self.attributes.get("usage.amount_in_pricing_units"):
                 self._pricing_amount = self.attributes.get("usage.amount_in_pricing_units")
             if self.attributes.get("price"):
                 self._price = self.attributes.get("price")
+            if self.attributes.get("credit_amount"):
+                self._credit_amount = self.attributes.get("credit_amount")
 
     def _update_data(self, row):  # noqa: C901
         """Update a data row with compute values."""
+
         service = choice(self.SERVICES)
         sku_options = self.SKU_MAPPING[service[0]]
         sku = choice(sku_options)
@@ -67,15 +71,16 @@ class CloudStorageGenerator(GCPGenerator):
         pricing_unit = sku[3]
         row["usage.unit"] = usage_unit
         row["usage.pricing_unit"] = pricing_unit
-        row["labels"] = self.determine_labels(self.LABELS)
-        row["system_labels"] = choice(self.SYSTEM_LABELS)
-        row["credits"] = "[]"
         row["cost_type"] = "regular"
         row["currency"] = "USD"
         row["currency_conversion_rate"] = 1
         row["usage.amount"] = self._gen_usage_unit_amount(usage_unit)
         row["usage.amount_in_pricing_units"] = self._gen_pricing_unit_amount(pricing_unit, row["usage.amount"])
-        row["cost"] = self._gen_cost(row["usage.amount_in_pricing_units"])
+        cost = self._gen_cost(row["usage.amount_in_pricing_units"])
+        row["cost"] = cost
+        credit, credit_total = self._gen_credit(self.credit_total, self._credit_amount)
+        self.credit_total = credit_total
+        row["credits"] = credit
         usage_date = datetime.strptime(row.get("usage_start_time"), "%Y-%m-%dT%H:%M:%S")
         row["invoice.month"] = f"{usage_date.year}{usage_date.month:02d}"
 
@@ -83,6 +88,10 @@ class CloudStorageGenerator(GCPGenerator):
             for key in self.attributes:
                 if key in self.column_labels:
                     row[key] = self.attributes[key]
+
+        row["labels"] = self.determine_labels(self.LABELS)
+        row["system_labels"] = choice(self.SYSTEM_LABELS)
+
         return row
 
     def generate_data(self, report_type=None):
@@ -118,13 +127,14 @@ class JSONLCloudStorageGenerator(CloudStorageGenerator):
         usage = {}
         usage["unit"] = usage_unit
         usage["pricing_unit"] = pricing_unit
-        row["labels"] = self.determine_labels(self.LABELS)
-        row["system_labels"] = choice(self.SYSTEM_LABELS)
         usage["amount"] = self._gen_usage_unit_amount(usage_unit)
         usage["amount_in_pricing_units"] = self._gen_pricing_unit_amount(pricing_unit, usage["amount"])
-        row["cost"] = self._gen_cost(usage["amount_in_pricing_units"])
+        cost = self._gen_cost(usage["amount_in_pricing_units"])
+        row["cost"] = cost
         row["usage"] = usage
-        row["credits"] = {}
+        credit, credit_total = self._gen_credit(self.credit_total, self._credit_amount, True)
+        self.credit_total = credit_total
+        row["credits"] = credit
         row["cost_type"] = "regular"
         row["currency"] = "USD"
         row["currency_conversion_rate"] = 1
@@ -141,6 +151,10 @@ class JSONLCloudStorageGenerator(CloudStorageGenerator):
                 elif key.split(".")[0] in self.column_labels:
                     outer_key, inner_key = key.split(".")
                     row[outer_key][inner_key] = self.attributes[key]
+
+        row["labels"] = self.determine_labels(self.LABELS)
+        row["system_labels"] = choice(self.SYSTEM_LABELS)
+
         return row
 
     def generate_data(self, report_type=None):
