@@ -767,19 +767,19 @@ def ocp_create_report(options):  # noqa: C901
             cr_status = {
                 "clusterID": "4e009161-4f40-42c8-877c-3e59f6baea3d",
                 "clusterVersion": "stable-4.6",
-                "api_url": "https://cloud.redhat.com",
+                "api_url": "https://console.redhat.com",
                 "authentication": {"type": "token"},
                 "packaging": {"max_reports_to_store": 30, "max_size_MB": 100},
                 "upload": {
                     "ingress_path": "/api/ingress/v1/upload",
-                    "upload": True,
+                    "upload": "True",
                     "upload_wait": 27,
                     "upload_cycle": 360,
                 },
                 "operator_commit": __version__,
                 "prometheus": {
-                    "prometheus_configured": True,
-                    "prometheus_connected": True,
+                    "prometheus_configured": "True",
+                    "prometheus_connected": "True",
                     "last_query_start_time": "2021-07-28T12:22:37Z",
                     "last_query_success_time": "2021-07-28T12:22:37Z",
                     "service_address": "https://thanos-querier.openshift-monitoring.svc:9091",
@@ -787,15 +787,16 @@ def ocp_create_report(options):  # noqa: C901
                 "reports": {
                     "report_month": "07",
                     "last_hour_queried": "2021-07-28 11:00:00 - 2021-07-28 11:59:59",
-                    "data_collected": True,
+                    "data_collected": "True",
                 },
                 "source": {
                     "sources_path": "/api/sources/v1.0/",
                     "name": "INSERT-SOURCE-NAME",
-                    "create_source": False,
+                    "create_source": "False",
                     "check_cycle": 1440,
                 },
             }
+            cr_status = json.dumps(cr_status)
             manifest_values = {
                 "ocp_cluster_id": cluster_id,
                 "ocp_assembly_id": ocp_assembly_id,
@@ -917,6 +918,17 @@ def gcp_create_report(options):  # noqa: C901
     elif static_report_data:
         generators = _get_generators(static_report_data.get("generators"))
         projects = static_report_data.get("projects")
+        processed_projects = copy.deepcopy(projects)
+        for i, project in enumerate(projects):
+            labels = []
+            static_labels = project.get("project.labels", [])
+            if static_labels:
+                for pair in static_labels.split(";"):
+                    key = pair.split(":")[0]
+                    value = pair.split(":")[1]
+                    labels.append({"key": key, "value": value})
+                processed_projects[i]["project.labels"] = json.dumps(labels)
+        projects = processed_projects
 
     else:
         generators = [
